@@ -56,13 +56,13 @@ extern "C" {
  * underneath it.
  */
 
-typedef enum {
+typedef enum { /*< prefix=GCONF_CLIENT >*/
   GCONF_CLIENT_PRELOAD_NONE,     /* don't preload anything */
   GCONF_CLIENT_PRELOAD_ONELEVEL, /* load entries directly under the directory. */
   GCONF_CLIENT_PRELOAD_RECURSIVE /* recurse the directory tree; possibly quite expensive! */
 } GConfClientPreloadType;
 
-typedef enum {
+typedef enum { /*< prefix=GCONF_CLIENT >*/
   GCONF_CLIENT_HANDLE_NONE,
   GCONF_CLIENT_HANDLE_UNRETURNED,
   GCONF_CLIENT_HANDLE_ALL
@@ -86,6 +86,7 @@ typedef void (*GConfClientErrorHandlerFunc) (GConfClient* client,
 #define GCONF_CLIENT_CLASS(klass)          (G_TYPE_CHECK_CLASS_CAST ((klass), GCONF_TYPE_CLIENT, GConfClientClass))
 #define GCONF_IS_CLIENT(obj)               (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GCONF_TYPE_CLIENT))
 #define GCONF_IS_CLIENT_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE ((klass), GCONF_TYPE_CLIENT))
+#define GCONF_CLIENT_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), GCONF_TYPE_CLIENT, GConfClientClass))
 
 struct _GConfClient
 {
@@ -98,6 +99,11 @@ struct _GConfClient
   GHashTable* dir_hash;
   GHashTable* cache_hash;
   GConfListeners* listeners;
+  GSList *notify_list;
+  guint notify_handler;
+  int pending_notify_count;
+  gpointer pad1;
+  int pad2;  
 };
 
 struct _GConfClientClass
@@ -132,6 +138,10 @@ struct _GConfClientClass
      something. */
   void (* error)            (GConfClient* client,
                              GError* error);
+
+  GFunc pad1;
+  GFunc pad2;
+  GFunc pad3;
 };
 
 
@@ -146,7 +156,7 @@ GConfClient*      gconf_client_get_for_engine (GConfEngine* engine);
 /* Add a directory to monitor and emit the value_changed signal and
    key notifications for.  Optionally pre-load the contents of this
    directory, much faster if you plan to access most of the directory
-   contents. You can't add overlapping directories.
+   contents.
 */
 
 void              gconf_client_add_dir     (GConfClient* client,
